/*
 [ GPL ]
 
 Code by JaeHyuk Cho <mailto:minzkn@infoeq.com> Made in KOREA

 http://kldp.net
 http://minzkn.pe.ky
*/

#ifndef DEF_HEADER_mixer_h 
#define DEF_HEADER_mixer_h "mixer.h"

#define DEF_MIXER_GET  (0)
#define DEF_MIXER_SET  (1)
#define DEF_MIXER_KEEP (-1)

#ifdef __cplusplus
extern "C"{
#endif

#ifndef DEF_SOURCE_mixer_c
/*
 ==================================================
  Mixer argument
 ==================================================

 - See also /usr/include/linux/soundcard.h

 s_DeviceName   = NULL(g_DefaultMixerDeviceName = "/dev/mixer")
 
 s_Channel      = SOUND_MIXER_{CHANNEL_NAME}
 s_ChannelMask  = SOUND_MASK_{CHANNEL_NAME}

 {CHANNEL_NAME} = VOLUME, BASS, TREBLE, SYNTH, 
                  PCM, SPEAKER, LINE, LINE, 
                  MIC, CD, IMIX, ALTPCM, 
                  RECLEV, IGAIN, OGAIN, LINE1, 
                  LINE2, LINE3, DIGITAL1, DIGITAL2, 
                  DIGITAL3, PHONEIN, PHONEOUT, RADIO, 
                  VIDEO, MONITOR, ...

 DEF_MIXER_KEEP = Keep old value	  
		  
 s_Left         = 0 ~ 100 | DEF_MIXER_KEEP
 s_Right        = 0 ~ 100 | DEF_MIXER_KEEP
 s_Mute         = 0 | 1 | DEF_MIXER_KEEP
*/

extern int MZ_GetMixer(const char *s_DeviceName, int s_Channel, int *s_Left, int *s_Right, int *s_Mute);
extern int MZ_GetVolume(const char *s_DeviceName, int s_Channel, int *s_Left, int *s_Right);
extern int MZ_GetMuteStatus(const char *s_DeviceName, int s_Channel);
extern int MZ_GetMute(const char *s_DeviceName, int s_Channel);
extern int MZ_SetMixer(const char *s_DeviceName, int s_Channel, int s_Left, int s_Right, int s_Mute);
extern int MZ_SetVolume(const char *s_DeviceName, int s_Channel, int s_Left, int s_Right);
extern int MZ_SetMuteStatus(const char *s_DeviceName, int s_Channel, int s_Mute);
extern int MZ_SetMute(const char *s_DeviceName, int s_Channel, int s_Mute);
extern int MZ_SetMixerMask(const char *s_DeviceName, int s_ChannelMask, int s_Left, int s_Right, int s_Mute);
extern int MZ_SetVolumeMask(const char *s_DeviceName, int s_ChannelMask, int s_Left, int s_Right);
extern int MZ_SetMuteStatusMask(const char *s_DeviceName, int s_ChannelMask, int s_Mute);
extern int MZ_SetMuteMask(const char *s_DeviceName, int s_ChannelMask, int s_Mute);

extern const int c_SoundDevices;       /* Set SOUND_MIXER_NRDEVICES */
extern const char *c_MixerName[];      /* Set SOUND_DEVICE_NAMES */ 
extern char *g_DefaultMixerDeviceName; /* Default "/dev/mixer" */
#endif

#ifdef __cplusplus
}
#endif

#endif

/* End of header */
